// SPDX-License-Identifier: BSD-3-Clause

package query_test

import (
	"testing"

	"git.froth.zone/sam/awl/cli"
	"git.froth.zone/sam/awl/internal/helpers"
	"git.froth.zone/sam/awl/query"
	"git.froth.zone/sam/awl/util"
	"github.com/miekg/dns"
	"gotest.tools/v3/assert"
)

func TestResolve(t *testing.T) {
	t.Parallel()
	opts := cli.Options{
		Logger: util.InitLogger(0),
		Port:   53,
		Request: helpers.Request{
			Server: "8.8.4.4",
			Type:   dns.TypeA,
			Name:   "example.com.",
		},
	}
	resolver, err := query.LoadResolver(opts.Request.Server, opts)
	assert.NilError(t, err)
	msg := new(dns.Msg)
	msg.SetQuestion(opts.Request.Name, opts.Request.Type)
	res, err := resolver.LookUp(msg)
	assert.NilError(t, err)
	assert.Assert(t, res != helpers.Response{})
}

func TestTruncate(t *testing.T) {
	t.Parallel()
	opts := cli.Options{
		Logger: util.InitLogger(0),
		Port:   5301,
		Request: helpers.Request{
			Server: "madns.binarystar.systems",
			Type:   dns.TypeTXT,
			Name:   "limit.txt.example.",
		},
	}
	resolver, err := query.LoadResolver(opts.Request.Server, opts)
	assert.NilError(t, err)
	msg := new(dns.Msg)
	msg.SetQuestion(opts.Request.Name, opts.Request.Type)
	res, err := resolver.LookUp(msg)
	assert.NilError(t, err)
	assert.Assert(t, res != helpers.Response{})
}
